=============================================
MontePetro
=============================================
Probabilistic Reserve Estimation in Python
=============================================

This package provides a library to perform basic monte carlo estimation of property distributions in native python.
The package was originaly intended to estimate oil and gas reserves in multi-regional domains
from petrophysical datasets, but can be applied to a variety of problems.